@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "thrift" "2026.3.2.0"
+(define-package "thrift" "20251124.952"
   "Major mode for fbthrift and Apache Thrift files."
   '((emacs "24"))
   :url "https://github.com/facebook/fbthrift"
-  :commit "1fcbcb06f09f70bdd53edb3c76b5b111b56313e0"
-  :revdesc "1fcbcb06f09f"
+  :commit "d08a6910d620c8560d2a9af574937d11bfb92388"
+  :revdesc "d08a6910d620"
   :keywords '("languages"))
